import javax.jms.*;
import javax.naming.*;
import java.util.*;
import java.io.*;
import java.text.*;

/*
 * Copyright (c) 2000 IIT GmbH, Bremen/Germany. All Rights Reserved.
 * 
 * IIT grants you ("Licensee") a non-exclusive, royalty free, license to use,
 * modify and redistribute this software in source and binary code form,
 * provided that i) this copyright notice and license appear on all copies of
 * the software; and ii) Licensee does not utilize the software in a manner
 * which is disparaging to IIT.
 *
 * This software is provided "AS IS," without a warranty of any kind. ALL
 * EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY
 * IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR
 * NON-INFRINGEMENT, ARE HEREBY EXCLUDED. IIT AND ITS LICENSORS SHALL NOT BE
 * LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING
 * OR DISTRIBUTING THE SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL IIT OR ITS
 * LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT,
 * INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER
 * CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF
 * OR INABILITY TO USE SOFTWARE, EVEN IF IIT HAS BEEN ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 *
 * This software is not designed or intended for use in on-line control of
 * aircraft, air traffic, aircraft navigation or aircraft communications; or in
 * the design, construction, operation or maintenance of any nuclear
 * facility. Licensee represents and warrants that it will not use or
 * redistribute the Software for such purposes.
 */

/**
 * TestMailer is an example on how to use the SMTP Mailer Extension Swiftlet.
 * It reads the appropriate properties as 'from', 'to' etc from the command
 * line, sends a message to the queue 'mailout' and waits for a receipt. The
 * program requires the Extension Swiftlet to be installed with the install.cli
 * script and having an alias of the mailqueue of 'mailout' defined.
 *
 * @author IIT GmbH, Bremen/Germany
 */

public class TestMailer
{
	static SimpleDateFormat formatter = new SimpleDateFormat("EEE, dd MMM yyyy HH:mm:ss z", Locale.US);

	public static void main(String[] args)
	{
		try {
			System.out.println("Lookup...");
			Hashtable env = new Hashtable();
			env.put(Context.INITIAL_CONTEXT_FACTORY,"com.swiftmq.jndi.InitialContextFactoryImpl");
			env.put(Context.PROVIDER_URL,"smqp://localhost:4001/timeout=10000");
			InitialContext ctx = new InitialContext(env);
			QueueConnectionFactory tcf = (QueueConnectionFactory)ctx.lookup("plainsocket@router1");
			Queue mailqueue = (Queue)ctx.lookup("mailout");
			ctx.close();
			
			String from = null;
			String to = null;
			String replyto = null;
			String cc = null;
			String subject = null;
			String body = null;
			
			BufferedReader inReader = new BufferedReader(new InputStreamReader(System.in));
			
			System.out.print("From: "); 
			from = inReader.readLine();
			System.out.print("To: "); 
			to = inReader.readLine();
			System.out.print("ReplyTo: "); 
			replyto = inReader.readLine();
			System.out.print("CC: "); 
			cc = inReader.readLine();
			System.out.print("Subject: "); 
			subject = inReader.readLine();
			System.out.println("Enter the mail body below. The word QUIT on a single line ends the input.");
			String s = null;
			StringBuffer bodyBuffer = new StringBuffer();
			while (true)
			{
				s = inReader.readLine();
				if (s != null && s.trim().equals("QUIT"))
					break;
				bodyBuffer.append(s);
				bodyBuffer.append("\r\n");
			}
			body = bodyBuffer.toString();
			System.out.println("Sending the mail...");
			
			QueueConnection connection = tcf.createQueueConnection();
			connection.start();
			QueueSession session = connection.createQueueSession(false,Session.AUTO_ACKNOWLEDGE);
			TemporaryQueue responseQueue = session.createTemporaryQueue();
			QueueSender sender = session.createSender(mailqueue);
			TextMessage msg = session.createTextMessage();
			msg.setJMSReplyTo(responseQueue);
			if (from != null && from.trim().length() > 0)
				msg.setStringProperty("from",from);
			if (to != null && to.trim().length() > 0)
				msg.setStringProperty("to",to);
			if (replyto != null && replyto.trim().length() > 0)
				msg.setStringProperty("replyto",replyto);
			if (cc != null && cc.trim().length() > 0)
				msg.setStringProperty("cc",cc);
			if (subject != null && subject.trim().length() > 0)
				msg.setStringProperty("subject",subject);
			if (body != null && body.trim().length() > 0)
				msg.setText(body);
			sender.send(msg);
			QueueReceiver receiver = session.createReceiver(responseQueue);
			TextMessage response = (TextMessage)receiver.receive();
			if (response.getBooleanProperty("status"))
				System.out.println("Successfully sent, deliveryTime: "+formatter.format(new Date(response.getLongProperty("deliverytime"))));
			else
				System.out.println("Sent failed, reason: "+response.getText());
			connection.close();
		} catch (Exception e)
		{
			System.err.println("Exception: "+e);
			System.exit(-1);
		}
	}
}

